# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: app/app_logs_payload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.app import app_definition_pb2 as app_dot_app__definition__pb2
from union.internal.app import replica_definition_pb2 as app_dot_replica__definition__pb2
from union.internal.logs.dataplane import payload_pb2 as logs_dot_dataplane_dot_payload__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61pp/app_logs_payload.proto\x12\x0c\x63loudidl.app\x1a\x18\x61pp/app_definition.proto\x1a\x1c\x61pp/replica_definition.proto\x1a\x1clogs/dataplane/payload.proto\x1a\x17validate/validate.proto\"\xa9\x01\n\x0fTailLogsRequest\x12;\n\x06\x61pp_id\x18\x01 \x01(\x0b\x32\x18.cloudidl.app.IdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\x05\x61ppId\x12J\n\nreplica_id\x18\x02 \x01(\x0b\x32\x1f.cloudidl.app.ReplicaIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\treplicaIdB\r\n\x06target\x12\x03\xf8\x42\x01\"T\n\x15ReplicaIdentifierList\x12;\n\x08replicas\x18\x01 \x03(\x0b\x32\x1f.cloudidl.app.ReplicaIdentifierR\x08replicas\"\xbb\x01\n\x08LogLines\x12\x18\n\x05lines\x18\x01 \x03(\tB\x02\x18\x01R\x05lines\x12H\n\nreplica_id\x18\x02 \x01(\x0b\x32\x1f.cloudidl.app.ReplicaIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\treplicaId\x12K\n\x10structured_lines\x18\x03 \x03(\x0b\x32 .cloudidl.logs.dataplane.LogLineR\x0fstructuredLines\";\n\rLogLinesBatch\x12*\n\x04logs\x18\x01 \x03(\x0b\x32\x16.cloudidl.app.LogLinesR\x04logs\"\xfd\x01\n\x10TailLogsResponse\x12K\n\x08replicas\x18\x01 \x01(\x0b\x32#.cloudidl.app.ReplicaIdentifierListB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\x08replicas\x12L\n\tlog_lines\x18\x02 \x01(\x0b\x32!.cloudidl.logs.dataplane.LogLinesB\n\x18\x01\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\x08logLines\x12\x41\n\x07\x62\x61tches\x18\x03 \x01(\x0b\x32\x1b.cloudidl.app.LogLinesBatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00R\x07\x62\x61tchesB\x0b\n\x04resp\x12\x03\xf8\x42\x01\x42\xa2\x01\n\x10\x63om.cloudidl.appB\x13\x41ppLogsPayloadProtoH\x02P\x01Z&github.com/unionai/cloud/gen/pb-go/app\xa2\x02\x03\x43\x41X\xaa\x02\x0c\x43loudidl.App\xca\x02\x0c\x43loudidl\\App\xe2\x02\x18\x43loudidl\\App\\GPBMetadata\xea\x02\rCloudidl::Appb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'app.app_logs_payload_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020com.cloudidl.appB\023AppLogsPayloadProtoH\002P\001Z&github.com/unionai/cloud/gen/pb-go/app\242\002\003CAX\252\002\014Cloudidl.App\312\002\014Cloudidl\\App\342\002\030Cloudidl\\App\\GPBMetadata\352\002\rCloudidl::App'
  _TAILLOGSREQUEST.oneofs_by_name['target']._options = None
  _TAILLOGSREQUEST.oneofs_by_name['target']._serialized_options = b'\370B\001'
  _TAILLOGSREQUEST.fields_by_name['app_id']._options = None
  _TAILLOGSREQUEST.fields_by_name['app_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TAILLOGSREQUEST.fields_by_name['replica_id']._options = None
  _TAILLOGSREQUEST.fields_by_name['replica_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LOGLINES.fields_by_name['lines']._options = None
  _LOGLINES.fields_by_name['lines']._serialized_options = b'\030\001'
  _LOGLINES.fields_by_name['replica_id']._options = None
  _LOGLINES.fields_by_name['replica_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TAILLOGSRESPONSE.oneofs_by_name['resp']._options = None
  _TAILLOGSRESPONSE.oneofs_by_name['resp']._serialized_options = b'\370B\001'
  _TAILLOGSRESPONSE.fields_by_name['replicas']._options = None
  _TAILLOGSRESPONSE.fields_by_name['replicas']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TAILLOGSRESPONSE.fields_by_name['log_lines']._options = None
  _TAILLOGSRESPONSE.fields_by_name['log_lines']._serialized_options = b'\030\001\372B\005\212\001\002\020\001'
  _TAILLOGSRESPONSE.fields_by_name['batches']._options = None
  _TAILLOGSRESPONSE.fields_by_name['batches']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_TAILLOGSREQUEST']._serialized_start=156
  _globals['_TAILLOGSREQUEST']._serialized_end=325
  _globals['_REPLICAIDENTIFIERLIST']._serialized_start=327
  _globals['_REPLICAIDENTIFIERLIST']._serialized_end=411
  _globals['_LOGLINES']._serialized_start=414
  _globals['_LOGLINES']._serialized_end=601
  _globals['_LOGLINESBATCH']._serialized_start=603
  _globals['_LOGLINESBATCH']._serialized_end=662
  _globals['_TAILLOGSRESPONSE']._serialized_start=665
  _globals['_TAILLOGSRESPONSE']._serialized_end=918
# @@protoc_insertion_point(module_scope)
