from union.internal.app import app_logs_payload_pb2 as _app_logs_payload_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
