# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: authorizer/definition.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.common import deployment_pb2 as common_dot_deployment__pb2
from union.internal.common import identifier_pb2 as common_dot_identifier__pb2
from union.internal.common import identity_pb2 as common_dot_identity__pb2
from union.internal.common import policy_pb2 as common_dot_policy__pb2
from union.internal.common import role_pb2 as common_dot_role__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61uthorizer/definition.proto\x12\x13\x63loudidl.authorizer\x1a\x17\x63ommon/deployment.proto\x1a\x17\x63ommon/identifier.proto\x1a\x15\x63ommon/identity.proto\x1a\x13\x63ommon/policy.proto\x1a\x11\x63ommon/role.proto\"\x85\x01\n\x0eRoleAssignment\x12\x38\n\x07role_id\x18\x01 \x01(\x0b\x32\x1f.cloudidl.common.RoleIdentifierR\x06roleId\x12\x39\n\nidentities\x18\x02 \x03(\x0b\x32\x19.cloudidl.common.IdentityR\nidentities\"\x8d\x01\n\x10PolicyAssignment\x12>\n\tpolicy_id\x18\x01 \x01(\x0b\x32!.cloudidl.common.PolicyIdentifierR\x08policyId\x12\x39\n\nidentities\x18\x02 \x03(\x0b\x32\x19.cloudidl.common.IdentityR\nidentities\"\xb1\x01\n\x12IdentityAssignment\x12\x35\n\x08identity\x18\x01 \x01(\x0b\x32\x19.cloudidl.common.IdentityR\x08identity\x12/\n\x05roles\x18\x02 \x03(\x0b\x32\x15.cloudidl.common.RoleB\x02\x18\x01R\x05roles\x12\x33\n\x08policies\x18\x03 \x03(\x0b\x32\x17.cloudidl.common.PolicyR\x08policies\"\xc1\x01\n\x13OrganizationOptions\x12U\n\x12\x61uthorization_type\x18\x01 \x01(\x0e\x32&.cloudidl.authorizer.AuthorizationTypeR\x11\x61uthorizationType\x12\x16\n\x06parent\x18\x02 \x01(\tR\x06parent\x12;\n\ndeployment\x18\x03 \x01(\x0e\x32\x1b.cloudidl.common.DeploymentR\ndeployment*T\n\x11\x41uthorizationType\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14TYPE_DEPRECATED_ROLE\x10\x01\x12\x0f\n\x0bTYPE_POLICY\x10\x02\x42\xc8\x01\n\x17\x63om.cloudidl.authorizerB\x0f\x44\x65\x66initionProtoH\x02P\x01Z-github.com/unionai/cloud/gen/pb-go/authorizer\xa2\x02\x03\x43\x41X\xaa\x02\x13\x43loudidl.Authorizer\xca\x02\x13\x43loudidl\\Authorizer\xe2\x02\x1f\x43loudidl\\Authorizer\\GPBMetadata\xea\x02\x14\x43loudidl::Authorizerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'authorizer.definition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.cloudidl.authorizerB\017DefinitionProtoH\002P\001Z-github.com/unionai/cloud/gen/pb-go/authorizer\242\002\003CAX\252\002\023Cloudidl.Authorizer\312\002\023Cloudidl\\Authorizer\342\002\037Cloudidl\\Authorizer\\GPBMetadata\352\002\024Cloudidl::Authorizer'
  _IDENTITYASSIGNMENT.fields_by_name['roles']._options = None
  _IDENTITYASSIGNMENT.fields_by_name['roles']._serialized_options = b'\030\001'
  _globals['_AUTHORIZATIONTYPE']._serialized_start=821
  _globals['_AUTHORIZATIONTYPE']._serialized_end=905
  _globals['_ROLEASSIGNMENT']._serialized_start=166
  _globals['_ROLEASSIGNMENT']._serialized_end=299
  _globals['_POLICYASSIGNMENT']._serialized_start=302
  _globals['_POLICYASSIGNMENT']._serialized_end=443
  _globals['_IDENTITYASSIGNMENT']._serialized_start=446
  _globals['_IDENTITYASSIGNMENT']._serialized_end=623
  _globals['_ORGANIZATIONOPTIONS']._serialized_start=626
  _globals['_ORGANIZATIONOPTIONS']._serialized_end=819
# @@protoc_insertion_point(module_scope)
