import os

REMOTE_MODEL_PATH = os.getenv("UNION_MODEL_LOADER_REMOTE_MODEL_PATH")
LOCAL_MODEL_PATH = os.getenv("UNION_MODEL_LOADER_LOCAL_MODEL_PATH", "/srv/model")
CHUNK_SIZE = int(os.getenv("UNION_MODEL_LOADER_CHUNK_SIZE", str(16 * 1024 * 1024)))
MAX_CONCURRENCY = int(os.getenv("UNION_MODEL_LOADER_MAX_CONCURRENCY", str(32)))
STREAM_SAFETENSORS = os.getenv("UNION_MODEL_LOADER_STREAM_SAFETENSORS", "false").lower() == "true"
