from google.api import annotations_pb2 as _annotations_pb2
from union.internal.workspace import workspace_definition_payload_pb2 as _workspace_definition_payload_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
