# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workspace/workspace_definition.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.common import identity_pb2 as common_dot_identity__pb2
from flyteidl.admin import task_pb2 as flyteidl_dot_admin_dot_task__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from flyteidl.core import security_pb2 as flyteidl_dot_core_dot_security__pb2
from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$workspace/workspace_definition.proto\x12\x12\x63loudidl.workspace\x1a\x15\x63ommon/identity.proto\x1a\x19\x66lyteidl/admin/task.proto\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1c\x66lyteidl/core/security.proto\x1a\x19\x66lyteidl/core/tasks.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\xb5\x01\n\x1dWorkspaceDefinitionIdentifier\x12\x10\n\x03org\x18\x01 \x01(\tR\x03org\x12!\n\x07project\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x07project\x12\x1f\n\x06\x64omain\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x64omain\x12\x1b\n\x04name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12!\n\x07version\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x07version\"\xa3\x01\n\x13WorkspaceDefinition\x12K\n\x02id\x18\x01 \x01(\x0b\x32\x31.cloudidl.workspace.WorkspaceDefinitionIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\x12?\n\x04spec\x18\x02 \x01(\x0b\x32+.cloudidl.workspace.WorkspaceDefinitionSpecR\x04spec\"\xad\x07\n\x17WorkspaceDefinitionSpec\x12/\n\x11short_description\x18\x01 \x01(\tB\x02\x18\x01R\x10shortDescription\x12\x39\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x32\n\x07task_id\x18\x04 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\x06taskId\x12\x46\n\x05state\x18\x05 \x01(\x0e\x32,.cloudidl.workspace.WorkspaceDefinitionStateB\x02\x18\x01R\x05state\x12\x39\n\ttask_spec\x18\x06 \x01(\x0b\x32\x18.flyteidl.admin.TaskSpecB\x02\x18\x01R\x08taskSpec\x12\x36\n\tresources\x18\x07 \x01(\x0b\x32\x18.flyteidl.core.ResourcesR\tresources\x12O\n\x12\x65xtended_resources\x18\x08 \x01(\x0b\x32 .flyteidl.core.ExtendedResourcesR\x11\x65xtendedResources\x12\x1f\n\x0bttl_seconds\x18\t \x01(\x04R\nttlSeconds\x12I\n\x10security_context\x18\n \x01(\x0b\x32\x1e.flyteidl.core.SecurityContextR\x0fsecurityContext\x12X\n\x12python_environment\x18\x0b \x01(\x0b\x32%.cloudidl.workspace.PythonEnvironmentB\x02\x18\x01R\x11pythonEnvironment\x12U\n\x11\x63onda_environment\x18\x0c \x01(\x0b\x32$.cloudidl.workspace.CondaEnvironmentB\x02\x18\x01R\x10\x63ondaEnvironment\x12\x1d\n\non_startup\x18\r \x03(\tR\tonStartup\x12\'\n\x0f\x63ontainer_image\x18\x0e \x01(\tR\x0e\x63ontainerImage\x12%\n\x0eworkspace_root\x18\x0f \x01(\tR\rworkspaceRoot\x12\x1f\n\x0bworking_dir\x18\x10 \x01(\tR\nworkingDir\"3\n\x11PythonEnvironment\x12\x1a\n\x08packages\x18\x01 \x03(\tR\x08packages:\x02\x18\x01\"N\n\x10\x43ondaEnvironment\x12\x1a\n\x08packages\x18\x01 \x03(\tR\x08packages\x12\x1a\n\x08\x63hannels\x18\x02 \x03(\tR\x08\x63hannels:\x02\x18\x01\"\x90\x01\n\x1bWorkspaceDefinitionEntityId\x12\x10\n\x03org\x18\x01 \x01(\tR\x03org\x12!\n\x07project\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x07project\x12\x1f\n\x06\x64omain\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x64omain\x12\x1b\n\x04name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\"\x89\x02\n\rAuditMetadata\x12\x39\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12@\n\ncreated_by\x18\x03 \x01(\x0b\x32!.cloudidl.common.EnrichedIdentityR\tcreatedBy\x12@\n\nupdated_by\x18\x04 \x01(\x0b\x32!.cloudidl.common.EnrichedIdentityR\tupdatedBy\"\xa1\x02\n\x19WorkspaceDefinitionEntity\x12I\n\x02id\x18\x01 \x01(\x0b\x32/.cloudidl.workspace.WorkspaceDefinitionEntityIdB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\x12\x42\n\x05state\x18\x02 \x01(\x0e\x32,.cloudidl.workspace.WorkspaceDefinitionStateR\x05state\x12+\n\x11short_description\x18\x03 \x01(\tR\x10shortDescription\x12H\n\x0e\x61udit_metadata\x18\x04 \x01(\x0b\x32!.cloudidl.workspace.AuditMetadataR\rauditMetadata*\x96\x01\n\x18WorkspaceDefinitionState\x12*\n&WORKSPACE_DEFINITION_STATE_UNSPECIFIED\x10\x00\x12%\n!WORKSPACE_DEFINITION_STATE_ACTIVE\x10\x01\x12\'\n#WORKSPACE_DEFINITION_STATE_ARCHIVED\x10\x02\x42\xcb\x01\n\x16\x63om.cloudidl.workspaceB\x18WorkspaceDefinitionProtoH\x02P\x01Z,github.com/unionai/cloud/gen/pb-go/workspace\xa2\x02\x03\x43WX\xaa\x02\x12\x43loudidl.Workspace\xca\x02\x12\x43loudidl\\Workspace\xe2\x02\x1e\x43loudidl\\Workspace\\GPBMetadata\xea\x02\x13\x43loudidl::Workspaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workspace.workspace_definition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.cloudidl.workspaceB\030WorkspaceDefinitionProtoH\002P\001Z,github.com/unionai/cloud/gen/pb-go/workspace\242\002\003CWX\252\002\022Cloudidl.Workspace\312\002\022Cloudidl\\Workspace\342\002\036Cloudidl\\Workspace\\GPBMetadata\352\002\023Cloudidl::Workspace'
  _WORKSPACEDEFINITIONIDENTIFIER.fields_by_name['project']._options = None
  _WORKSPACEDEFINITIONIDENTIFIER.fields_by_name['project']._serialized_options = b'\372B\004r\002\020\001'
  _WORKSPACEDEFINITIONIDENTIFIER.fields_by_name['domain']._options = None
  _WORKSPACEDEFINITIONIDENTIFIER.fields_by_name['domain']._serialized_options = b'\372B\004r\002\020\001'
  _WORKSPACEDEFINITIONIDENTIFIER.fields_by_name['name']._options = None
  _WORKSPACEDEFINITIONIDENTIFIER.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _WORKSPACEDEFINITIONIDENTIFIER.fields_by_name['version']._options = None
  _WORKSPACEDEFINITIONIDENTIFIER.fields_by_name['version']._serialized_options = b'\372B\004r\002\020\001'
  _WORKSPACEDEFINITION.fields_by_name['id']._options = None
  _WORKSPACEDEFINITION.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _WORKSPACEDEFINITIONSPEC.fields_by_name['short_description']._options = None
  _WORKSPACEDEFINITIONSPEC.fields_by_name['short_description']._serialized_options = b'\030\001'
  _WORKSPACEDEFINITIONSPEC.fields_by_name['state']._options = None
  _WORKSPACEDEFINITIONSPEC.fields_by_name['state']._serialized_options = b'\030\001'
  _WORKSPACEDEFINITIONSPEC.fields_by_name['task_spec']._options = None
  _WORKSPACEDEFINITIONSPEC.fields_by_name['task_spec']._serialized_options = b'\030\001'
  _WORKSPACEDEFINITIONSPEC.fields_by_name['python_environment']._options = None
  _WORKSPACEDEFINITIONSPEC.fields_by_name['python_environment']._serialized_options = b'\030\001'
  _WORKSPACEDEFINITIONSPEC.fields_by_name['conda_environment']._options = None
  _WORKSPACEDEFINITIONSPEC.fields_by_name['conda_environment']._serialized_options = b'\030\001'
  _PYTHONENVIRONMENT._options = None
  _PYTHONENVIRONMENT._serialized_options = b'\030\001'
  _CONDAENVIRONMENT._options = None
  _CONDAENVIRONMENT._serialized_options = b'\030\001'
  _WORKSPACEDEFINITIONENTITYID.fields_by_name['project']._options = None
  _WORKSPACEDEFINITIONENTITYID.fields_by_name['project']._serialized_options = b'\372B\004r\002\020\001'
  _WORKSPACEDEFINITIONENTITYID.fields_by_name['domain']._options = None
  _WORKSPACEDEFINITIONENTITYID.fields_by_name['domain']._serialized_options = b'\372B\004r\002\020\001'
  _WORKSPACEDEFINITIONENTITYID.fields_by_name['name']._options = None
  _WORKSPACEDEFINITIONENTITYID.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _WORKSPACEDEFINITIONENTITY.fields_by_name['id']._options = None
  _WORKSPACEDEFINITIONENTITY.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_WORKSPACEDEFINITIONSTATE']._serialized_start=2392
  _globals['_WORKSPACEDEFINITIONSTATE']._serialized_end=2542
  _globals['_WORKSPACEDEFINITIONIDENTIFIER']._serialized_start=258
  _globals['_WORKSPACEDEFINITIONIDENTIFIER']._serialized_end=439
  _globals['_WORKSPACEDEFINITION']._serialized_start=442
  _globals['_WORKSPACEDEFINITION']._serialized_end=605
  _globals['_WORKSPACEDEFINITIONSPEC']._serialized_start=608
  _globals['_WORKSPACEDEFINITIONSPEC']._serialized_end=1549
  _globals['_PYTHONENVIRONMENT']._serialized_start=1551
  _globals['_PYTHONENVIRONMENT']._serialized_end=1602
  _globals['_CONDAENVIRONMENT']._serialized_start=1604
  _globals['_CONDAENVIRONMENT']._serialized_end=1682
  _globals['_WORKSPACEDEFINITIONENTITYID']._serialized_start=1685
  _globals['_WORKSPACEDEFINITIONENTITYID']._serialized_end=1829
  _globals['_AUDITMETADATA']._serialized_start=1832
  _globals['_AUDITMETADATA']._serialized_end=2097
  _globals['_WORKSPACEDEFINITIONENTITY']._serialized_start=2100
  _globals['_WORKSPACEDEFINITIONENTITY']._serialized_end=2389
# @@protoc_insertion_point(module_scope)
