# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: secret/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from union.internal.secret import payload_pb2 as secret_dot_payload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13secret/secret.proto\x12\x0f\x63loudidl.secret\x1a\x1cgoogle/api/annotations.proto\x1a\x14secret/payload.proto2\x86\x05\n\rSecretService\x12w\n\x0c\x43reateSecret\x12$.cloudidl.secret.CreateSecretRequest\x1a%.cloudidl.secret.CreateSecretResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/secrets/api/v1:\x01*\x12\x86\x01\n\x0cUpdateSecret\x12$.cloudidl.secret.UpdateSecretRequest\x1a%.cloudidl.secret.UpdateSecretResponse\")\x82\xd3\xe4\x93\x02#\x1a\x1e/secrets/api/v1/name/{id.name}:\x01*\x12z\n\tGetSecret\x12!.cloudidl.secret.GetSecretRequest\x1a\".cloudidl.secret.GetSecretResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/secrets/api/v1/name/{id.name}\x12\x83\x01\n\x0c\x44\x65leteSecret\x12$.cloudidl.secret.DeleteSecretRequest\x1a%.cloudidl.secret.DeleteSecretResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/secrets/api/v1/name/{id.name}\x12q\n\x0bListSecrets\x12#.cloudidl.secret.ListSecretsRequest\x1a$.cloudidl.secret.ListSecretsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/secrets/api/v1B\xac\x01\n\x13\x63om.cloudidl.secretB\x0bSecretProtoH\x02P\x01Z)github.com/unionai/cloud/gen/pb-go/secret\xa2\x02\x03\x43SX\xaa\x02\x0f\x43loudidl.Secret\xca\x02\x0f\x43loudidl\\Secret\xe2\x02\x1b\x43loudidl\\Secret\\GPBMetadata\xea\x02\x10\x43loudidl::Secretb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'secret.secret_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.cloudidl.secretB\013SecretProtoH\002P\001Z)github.com/unionai/cloud/gen/pb-go/secret\242\002\003CSX\252\002\017Cloudidl.Secret\312\002\017Cloudidl\\Secret\342\002\033Cloudidl\\Secret\\GPBMetadata\352\002\020Cloudidl::Secret'
  _SECRETSERVICE.methods_by_name['CreateSecret']._options = None
  _SECRETSERVICE.methods_by_name['CreateSecret']._serialized_options = b'\202\323\344\223\002\024\"\017/secrets/api/v1:\001*'
  _SECRETSERVICE.methods_by_name['UpdateSecret']._options = None
  _SECRETSERVICE.methods_by_name['UpdateSecret']._serialized_options = b'\202\323\344\223\002#\032\036/secrets/api/v1/name/{id.name}:\001*'
  _SECRETSERVICE.methods_by_name['GetSecret']._options = None
  _SECRETSERVICE.methods_by_name['GetSecret']._serialized_options = b'\202\323\344\223\002 \022\036/secrets/api/v1/name/{id.name}'
  _SECRETSERVICE.methods_by_name['DeleteSecret']._options = None
  _SECRETSERVICE.methods_by_name['DeleteSecret']._serialized_options = b'\202\323\344\223\002 *\036/secrets/api/v1/name/{id.name}'
  _SECRETSERVICE.methods_by_name['ListSecrets']._options = None
  _SECRETSERVICE.methods_by_name['ListSecrets']._serialized_options = b'\202\323\344\223\002\021\022\017/secrets/api/v1'
  _globals['_SECRETSERVICE']._serialized_start=93
  _globals['_SECRETSERVICE']._serialized_end=739
# @@protoc_insertion_point(module_scope)
