# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: identity/user_payload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.common import identifier_pb2 as common_dot_identifier__pb2
from union.internal.common import identity_pb2 as common_dot_identity__pb2
from union.internal.common import list_pb2 as common_dot_list__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bidentity/user_payload.proto\x12\x11\x63loudidl.identity\x1a\x17\x63ommon/identifier.proto\x1a\x15\x63ommon/identity.proto\x1a\x11\x63ommon/list.proto\x1a\x17validate/validate.proto\"L\n\x11\x43reateUserRequest\x12\x37\n\x04spec\x18\x01 \x01(\x0b\x32\x19.cloudidl.common.UserSpecB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x04spec\"E\n\x12\x43reateUserResponse\x12/\n\x02id\x18\x01 \x01(\x0b\x32\x1f.cloudidl.common.UserIdentifierR\x02id\"K\n\x0eGetUserRequest\x12\x39\n\x02id\x18\x01 \x01(\x0b\x32\x1f.cloudidl.common.UserIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\"<\n\x0fGetUserResponse\x12)\n\x04user\x18\x01 \x01(\x0b\x32\x15.cloudidl.common.UserR\x04user\"r\n\x11\x44\x65leteUserRequest\x12\x39\n\x02id\x18\x01 \x01(\x0b\x32\x1f.cloudidl.common.UserIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\x12\"\n\x0corganization\x18\x02 \x01(\tR\x0corganization\"\x14\n\x12\x44\x65leteUserResponse\"\xa2\x02\n\x10ListUsersRequest\x12\"\n\x0corganization\x18\x01 \x01(\tR\x0corganization\x12<\n\x07role_id\x18\x02 \x01(\x0b\x32\x1f.cloudidl.common.RoleIdentifierB\x02\x18\x01R\x06roleId\x12\x36\n\x07request\x18\x03 \x01(\x0b\x32\x1c.cloudidl.common.ListRequestR\x07request\x12\x32\n\x15include_support_staff\x18\x04 \x01(\x08R\x13includeSupportStaff\x12@\n\x1c\x65xclude_identity_assignments\x18\x05 \x01(\x08R\x1a\x65xcludeIdentityAssignments\"V\n\x11ListUsersResponse\x12+\n\x05users\x18\x01 \x03(\x0b\x32\x15.cloudidl.common.UserR\x05users\x12\x14\n\x05token\x18\x02 \x01(\tR\x05token\"\x17\n\x15ListUsersCountRequest\".\n\x16ListUsersCountResponse\x12\x14\n\x05\x63ount\x18\x01 \x01(\x03R\x05\x63ount\"L\n\x1dGetUserAndGroupsForOrgRequest\x12+\n\x0corganization\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0corganization\"M\n\x1eGetUserAndGroupsForOrgResponse\x12+\n\x05users\x18\x01 \x03(\x0b\x32\x15.cloudidl.common.UserR\x05usersB\xbd\x01\n\x15\x63om.cloudidl.identityB\x10UserPayloadProtoH\x02P\x01Z+github.com/unionai/cloud/gen/pb-go/identity\xa2\x02\x03\x43IX\xaa\x02\x11\x43loudidl.Identity\xca\x02\x11\x43loudidl\\Identity\xe2\x02\x1d\x43loudidl\\Identity\\GPBMetadata\xea\x02\x12\x43loudidl::Identityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'identity.user_payload_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.cloudidl.identityB\020UserPayloadProtoH\002P\001Z+github.com/unionai/cloud/gen/pb-go/identity\242\002\003CIX\252\002\021Cloudidl.Identity\312\002\021Cloudidl\\Identity\342\002\035Cloudidl\\Identity\\GPBMetadata\352\002\022Cloudidl::Identity'
  _CREATEUSERREQUEST.fields_by_name['spec']._options = None
  _CREATEUSERREQUEST.fields_by_name['spec']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETUSERREQUEST.fields_by_name['id']._options = None
  _GETUSERREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETEUSERREQUEST.fields_by_name['id']._options = None
  _DELETEUSERREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTUSERSREQUEST.fields_by_name['role_id']._options = None
  _LISTUSERSREQUEST.fields_by_name['role_id']._serialized_options = b'\030\001'
  _GETUSERANDGROUPSFORORGREQUEST.fields_by_name['organization']._options = None
  _GETUSERANDGROUPSFORORGREQUEST.fields_by_name['organization']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEUSERREQUEST']._serialized_start=142
  _globals['_CREATEUSERREQUEST']._serialized_end=218
  _globals['_CREATEUSERRESPONSE']._serialized_start=220
  _globals['_CREATEUSERRESPONSE']._serialized_end=289
  _globals['_GETUSERREQUEST']._serialized_start=291
  _globals['_GETUSERREQUEST']._serialized_end=366
  _globals['_GETUSERRESPONSE']._serialized_start=368
  _globals['_GETUSERRESPONSE']._serialized_end=428
  _globals['_DELETEUSERREQUEST']._serialized_start=430
  _globals['_DELETEUSERREQUEST']._serialized_end=544
  _globals['_DELETEUSERRESPONSE']._serialized_start=546
  _globals['_DELETEUSERRESPONSE']._serialized_end=566
  _globals['_LISTUSERSREQUEST']._serialized_start=569
  _globals['_LISTUSERSREQUEST']._serialized_end=859
  _globals['_LISTUSERSRESPONSE']._serialized_start=861
  _globals['_LISTUSERSRESPONSE']._serialized_end=947
  _globals['_LISTUSERSCOUNTREQUEST']._serialized_start=949
  _globals['_LISTUSERSCOUNTREQUEST']._serialized_end=972
  _globals['_LISTUSERSCOUNTRESPONSE']._serialized_start=974
  _globals['_LISTUSERSCOUNTRESPONSE']._serialized_end=1020
  _globals['_GETUSERANDGROUPSFORORGREQUEST']._serialized_start=1022
  _globals['_GETUSERANDGROUPSFORORGREQUEST']._serialized_end=1098
  _globals['_GETUSERANDGROUPSFORORGRESPONSE']._serialized_start=1100
  _globals['_GETUSERANDGROUPSFORORGRESPONSE']._serialized_end=1177
# @@protoc_insertion_point(module_scope)
