# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workspace/workspace_instance.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.common import identity_pb2 as common_dot_identity__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2
from union.internal.workspace import workspace_definition_pb2 as workspace_dot_workspace__definition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"workspace/workspace_instance.proto\x12\x12\x63loudidl.workspace\x1a\x15\x63ommon/identity.proto\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a$workspace/workspace_definition.proto\"\xa4\x01\n\x1bWorkspaceInstanceIdentifier\x12\x10\n\x03org\x18\x01 \x01(\tR\x03org\x12!\n\x07project\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x07project\x12\x1f\n\x06\x64omain\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x64omain\x12\x1b\n\x04name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12\x12\n\x04host\x18\x05 \x01(\tR\x04host\"\xfc\x02\n\x17WorkspaceInstanceStatus\x12X\n\x05phase\x18\x01 \x01(\x0e\x32\x42.cloudidl.workspace.WorkspaceInstanceStatus.WorkspaceInstancePhaseR\x05phase\"\x86\x02\n\x16WorkspaceInstancePhase\x12(\n$WORKSPACE_INSTANCE_PHASE_UNSPECIFIED\x10\x00\x12$\n WORKSPACE_INSTANCE_PHASE_PENDING\x10\x01\x12$\n WORKSPACE_INSTANCE_PHASE_RUNNING\x10\x02\x12(\n$WORKSPACE_INSTANCE_PHASE_TERMINATING\x10\x03\x12\'\n#WORKSPACE_INSTANCE_PHASE_TERMINATED\x10\x04\x12#\n\x1fWORKSPACE_INSTANCE_PHASE_FAILED\x10\x05\"\xf0\x03\n\x15WorkspaceInstanceSpec\x12\x43\n\x06status\x18\x01 \x01(\x0b\x32+.cloudidl.workspace.WorkspaceInstanceStatusR\x06status\x12\x35\n\x08identity\x18\x02 \x01(\x0b\x32\x19.cloudidl.common.IdentityR\x08identity\x12\x39\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12s\n\x17workspace_definition_id\x18\x05 \x01(\x0b\x32\x31.cloudidl.workspace.WorkspaceDefinitionIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x15workspaceDefinitionId\x12^\n\x15workflow_execution_id\x18\x06 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifierR\x13workflowExecutionId\x12\x10\n\x03uri\x18\x07 \x01(\tR\x03uri\"\xa7\x01\n\x11WorkspaceInstance\x12I\n\x02id\x18\x01 \x01(\x0b\x32/.cloudidl.workspace.WorkspaceInstanceIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\x12G\n\x04spec\x18\x02 \x01(\x0b\x32).cloudidl.workspace.WorkspaceInstanceSpecB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x04spec\"Y\n\x12WorkspaceInstances\x12\x43\n\tinstances\x18\x01 \x03(\x0b\x32%.cloudidl.workspace.WorkspaceInstanceR\tinstances\"Q\n\nStartEvent\x12\x43\n\tworkspace\x18\x01 \x01(\x0b\x32%.cloudidl.workspace.WorkspaceInstanceR\tworkspace\"\xad\x01\n\x0bUpdateEvent\x12R\n\x11updated_workspace\x18\x01 \x01(\x0b\x32%.cloudidl.workspace.WorkspaceInstanceR\x10updatedWorkspace\x12J\n\rold_workspace\x18\x02 \x01(\x0b\x32%.cloudidl.workspace.WorkspaceInstanceR\x0coldWorkspace\"L\n\tStopEvent\x12?\n\x02id\x18\x01 \x01(\x0b\x32/.cloudidl.workspace.WorkspaceInstanceIdentifierR\x02id\"P\n\rStoppingEvent\x12?\n\x02id\x18\x01 \x01(\x0b\x32/.cloudidl.workspace.WorkspaceInstanceIdentifierR\x02idB\xc9\x01\n\x16\x63om.cloudidl.workspaceB\x16WorkspaceInstanceProtoH\x02P\x01Z,github.com/unionai/cloud/gen/pb-go/workspace\xa2\x02\x03\x43WX\xaa\x02\x12\x43loudidl.Workspace\xca\x02\x12\x43loudidl\\Workspace\xe2\x02\x1e\x43loudidl\\Workspace\\GPBMetadata\xea\x02\x13\x43loudidl::Workspaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workspace.workspace_instance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.cloudidl.workspaceB\026WorkspaceInstanceProtoH\002P\001Z,github.com/unionai/cloud/gen/pb-go/workspace\242\002\003CWX\252\002\022Cloudidl.Workspace\312\002\022Cloudidl\\Workspace\342\002\036Cloudidl\\Workspace\\GPBMetadata\352\002\023Cloudidl::Workspace'
  _WORKSPACEINSTANCEIDENTIFIER.fields_by_name['project']._options = None
  _WORKSPACEINSTANCEIDENTIFIER.fields_by_name['project']._serialized_options = b'\372B\004r\002\020\001'
  _WORKSPACEINSTANCEIDENTIFIER.fields_by_name['domain']._options = None
  _WORKSPACEINSTANCEIDENTIFIER.fields_by_name['domain']._serialized_options = b'\372B\004r\002\020\001'
  _WORKSPACEINSTANCEIDENTIFIER.fields_by_name['name']._options = None
  _WORKSPACEINSTANCEIDENTIFIER.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _WORKSPACEINSTANCESPEC.fields_by_name['workspace_definition_id']._options = None
  _WORKSPACEINSTANCESPEC.fields_by_name['workspace_definition_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _WORKSPACEINSTANCE.fields_by_name['id']._options = None
  _WORKSPACEINSTANCE.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _WORKSPACEINSTANCE.fields_by_name['spec']._options = None
  _WORKSPACEINSTANCE.fields_by_name['spec']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_WORKSPACEINSTANCEIDENTIFIER']._serialized_start=210
  _globals['_WORKSPACEINSTANCEIDENTIFIER']._serialized_end=374
  _globals['_WORKSPACEINSTANCESTATUS']._serialized_start=377
  _globals['_WORKSPACEINSTANCESTATUS']._serialized_end=757
  _globals['_WORKSPACEINSTANCESTATUS_WORKSPACEINSTANCEPHASE']._serialized_start=495
  _globals['_WORKSPACEINSTANCESTATUS_WORKSPACEINSTANCEPHASE']._serialized_end=757
  _globals['_WORKSPACEINSTANCESPEC']._serialized_start=760
  _globals['_WORKSPACEINSTANCESPEC']._serialized_end=1256
  _globals['_WORKSPACEINSTANCE']._serialized_start=1259
  _globals['_WORKSPACEINSTANCE']._serialized_end=1426
  _globals['_WORKSPACEINSTANCES']._serialized_start=1428
  _globals['_WORKSPACEINSTANCES']._serialized_end=1517
  _globals['_STARTEVENT']._serialized_start=1519
  _globals['_STARTEVENT']._serialized_end=1600
  _globals['_UPDATEEVENT']._serialized_start=1603
  _globals['_UPDATEEVENT']._serialized_end=1776
  _globals['_STOPEVENT']._serialized_start=1778
  _globals['_STOPEVENT']._serialized_end=1854
  _globals['_STOPPINGEVENT']._serialized_start=1856
  _globals['_STOPPINGEVENT']._serialized_end=1936
# @@protoc_insertion_point(module_scope)
