# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: authorizer/authorizer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.authorizer import payload_pb2 as authorizer_dot_payload__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61uthorizer/authorizer.proto\x12\x13\x63loudidl.authorizer\x1a\x18\x61uthorizer/payload.proto\x1a\x1cgoogle/api/annotations.proto2\x8d \n\x11\x41uthorizerService\x12\x83\x01\n\tAuthorize\x12%.cloudidl.authorizer.AuthorizeRequest\x1a&.cloudidl.authorizer.AuthorizeResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/authorizer/api/v1/authorize:\x01*\x12\x93\x01\n\x0e\x43reateIdentity\x12*.cloudidl.authorizer.CreateIdentityRequest\x1a+.cloudidl.authorizer.CreateIdentityResponse\"(\x82\xd3\xe4\x93\x02\"\"\x1d/authorizer/api/v1/identities:\x01*\x12\x90\x01\n\x0e\x44\x65leteIdentity\x12*.cloudidl.authorizer.DeleteIdentityRequest\x1a+.cloudidl.authorizer.DeleteIdentityResponse\"%\x82\xd3\xe4\x93\x02\x1f*\x1d/authorizer/api/v1/identities\x12\x9f\x01\n\x0e\x41ssignIdentity\x12*.cloudidl.authorizer.AssignIdentityRequest\x1a+.cloudidl.authorizer.AssignIdentityResponse\"4\x82\xd3\xe4\x93\x02.\x1a)/authorizer/api/v1/identities/assignments:\x01*\x12\xa5\x01\n\x10UnassignIdentity\x12,.cloudidl.authorizer.UnassignIdentityRequest\x1a-.cloudidl.authorizer.UnassignIdentityResponse\"4\x82\xd3\xe4\x93\x02.*)/authorizer/api/v1/identities/assignments:\x01*\x12\xc8\x02\n\x16GetIdentityAssignments\x12\x31.cloudidl.authorizer.GetIdentityAssignmentRequest\x1a\x32.cloudidl.authorizer.GetIdentityAssignmentResponse\"\xc6\x01\x82\xd3\xe4\x93\x02\xbf\x01\x12)/authorizer/api/v1/identities/assignmentsZO\x12M/authorizer/api/v1/applications/assignments/{identity.application_id.subject}ZA\x12?/authorizer/api/v1/users/assignments/{identity.user_id.subject}\x12\xbc\x01\n\x17ListIdentityAssignments\x12\x33.cloudidl.authorizer.ListIdentityAssignmentsRequest\x1a\x34.cloudidl.authorizer.ListIdentityAssignmentsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./authorizer/api/v1/identities/assignments/list\x12\xb1\x01\n\x13GetPolicyAssignment\x12/.cloudidl.authorizer.GetPolicyAssignmentRequest\x1a\x30.cloudidl.authorizer.GetPolicyAssignmentResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//authorizer/api/v1/policy_assignments/{id.name}\x12\x92\x01\n\x0e\x43reateResource\x12*.cloudidl.authorizer.CreateResourceRequest\x1a+.cloudidl.authorizer.CreateResourceResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/authorizer/api/v1/resources:\x01*\x12\x92\x01\n\x0e\x44\x65leteResource\x12*.cloudidl.authorizer.DeleteResourceRequest\x1a+.cloudidl.authorizer.DeleteResourceResponse\"\'\x82\xd3\xe4\x93\x02!*\x1c/authorizer/api/v1/resources:\x01*\x12\xa2\x01\n\x12\x43reateOrganization\x12..cloudidl.authorizer.CreateOrganizationRequest\x1a/.cloudidl.authorizer.CreateOrganizationResponse\"+\x82\xd3\xe4\x93\x02%\" /authorizer/api/v1/organizations:\x01*\x12\xa5\x01\n\x0fGetOrganization\x12+.cloudidl.authorizer.GetOrganizationRequest\x1a,.cloudidl.authorizer.GetOrganizationResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//authorizer/api/v1/organizations/{organization}\x12\xb1\x01\n\x12\x44\x65leteOrganization\x12..cloudidl.authorizer.DeleteOrganizationRequest\x1a/.cloudidl.authorizer.DeleteOrganizationResponse\":\x82\xd3\xe4\x93\x02\x34*//authorizer/api/v1/organizations/{organization}:\x01*\x12\x8b\x01\n\x0c\x43reatePolicy\x12(.cloudidl.authorizer.CreatePolicyRequest\x1a).cloudidl.authorizer.CreatePolicyResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/authorizer/api/v1/policies:\x01*\x12\x89\x01\n\tGetPolicy\x12%.cloudidl.authorizer.GetPolicyRequest\x1a&.cloudidl.authorizer.GetPolicyResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/authorizer/api/v1/policies/{id.name}\x12\x92\x01\n\x0c\x44\x65letePolicy\x12(.cloudidl.authorizer.DeletePolicyRequest\x1a).cloudidl.authorizer.DeletePolicyResponse\"-\x82\xd3\xe4\x93\x02\'*%/authorizer/api/v1/policies/{id.name}\x12\x88\x01\n\x0cListPolicies\x12(.cloudidl.authorizer.ListPoliciesRequest\x1a).cloudidl.authorizer.ListPoliciesResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/authorizer/api/v1/policies\x12\xba\x01\n\x13\x43reatePolicyBinding\x12/.cloudidl.authorizer.CreatePolicyBindingRequest\x1a\x30.cloudidl.authorizer.CreatePolicyBindingResponse\"@\x82\xd3\xe4\x93\x02:\"5/authorizer/api/v1/policies/{policy_id.name}/bindings:\x01*\x12\xba\x01\n\x13\x44\x65letePolicyBinding\x12/.cloudidl.authorizer.DeletePolicyBindingRequest\x1a\x30.cloudidl.authorizer.DeletePolicyBindingResponse\"@\x82\xd3\xe4\x93\x02:*5/authorizer/api/v1/policies/{policy_id.name}/bindings:\x01*\x12\x82\x01\n\nCreateRole\x12&.cloudidl.authorizer.CreateRoleRequest\x1a\'.cloudidl.authorizer.CreateRoleResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/authorizer/api/v1/roles:\x01*\x12\x80\x01\n\x07GetRole\x12#.cloudidl.authorizer.GetRoleRequest\x1a$.cloudidl.authorizer.GetRoleResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/authorizer/api/v1/roles/{id.name}\x12\x89\x01\n\nDeleteRole\x12&.cloudidl.authorizer.DeleteRoleRequest\x1a\'.cloudidl.authorizer.DeleteRoleResponse\"*\x82\xd3\xe4\x93\x02$*\"/authorizer/api/v1/roles/{id.name}\x12|\n\tListRoles\x12%.cloudidl.authorizer.ListRolesRequest\x1a&.cloudidl.authorizer.ListRolesResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/authorizer/api/v1/roles\x12\xa6\x01\n\x10\x43reateRoleAction\x12,.cloudidl.authorizer.CreateRoleActionRequest\x1a-.cloudidl.authorizer.CreateRoleActionResponse\"5\x82\xd3\xe4\x93\x02/\"*/authorizer/api/v1/roles/{id.name}/actions:\x01*\x12\xa6\x01\n\x10\x44\x65leteRoleAction\x12,.cloudidl.authorizer.DeleteRoleActionRequest\x1a-.cloudidl.authorizer.DeleteRoleActionResponse\"5\x82\xd3\xe4\x93\x02/**/authorizer/api/v1/roles/{id.name}/actions:\x01*B\xc8\x01\n\x17\x63om.cloudidl.authorizerB\x0f\x41uthorizerProtoH\x02P\x01Z-github.com/unionai/cloud/gen/pb-go/authorizer\xa2\x02\x03\x43\x41X\xaa\x02\x13\x43loudidl.Authorizer\xca\x02\x13\x43loudidl\\Authorizer\xe2\x02\x1f\x43loudidl\\Authorizer\\GPBMetadata\xea\x02\x14\x43loudidl::Authorizerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'authorizer.authorizer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.cloudidl.authorizerB\017AuthorizerProtoH\002P\001Z-github.com/unionai/cloud/gen/pb-go/authorizer\242\002\003CAX\252\002\023Cloudidl.Authorizer\312\002\023Cloudidl\\Authorizer\342\002\037Cloudidl\\Authorizer\\GPBMetadata\352\002\024Cloudidl::Authorizer'
  _AUTHORIZERSERVICE.methods_by_name['Authorize']._options = None
  _AUTHORIZERSERVICE.methods_by_name['Authorize']._serialized_options = b'\202\323\344\223\002!\"\034/authorizer/api/v1/authorize:\001*'
  _AUTHORIZERSERVICE.methods_by_name['CreateIdentity']._options = None
  _AUTHORIZERSERVICE.methods_by_name['CreateIdentity']._serialized_options = b'\202\323\344\223\002\"\"\035/authorizer/api/v1/identities:\001*'
  _AUTHORIZERSERVICE.methods_by_name['DeleteIdentity']._options = None
  _AUTHORIZERSERVICE.methods_by_name['DeleteIdentity']._serialized_options = b'\202\323\344\223\002\037*\035/authorizer/api/v1/identities'
  _AUTHORIZERSERVICE.methods_by_name['AssignIdentity']._options = None
  _AUTHORIZERSERVICE.methods_by_name['AssignIdentity']._serialized_options = b'\202\323\344\223\002.\032)/authorizer/api/v1/identities/assignments:\001*'
  _AUTHORIZERSERVICE.methods_by_name['UnassignIdentity']._options = None
  _AUTHORIZERSERVICE.methods_by_name['UnassignIdentity']._serialized_options = b'\202\323\344\223\002.*)/authorizer/api/v1/identities/assignments:\001*'
  _AUTHORIZERSERVICE.methods_by_name['GetIdentityAssignments']._options = None
  _AUTHORIZERSERVICE.methods_by_name['GetIdentityAssignments']._serialized_options = b'\202\323\344\223\002\277\001\022)/authorizer/api/v1/identities/assignmentsZO\022M/authorizer/api/v1/applications/assignments/{identity.application_id.subject}ZA\022?/authorizer/api/v1/users/assignments/{identity.user_id.subject}'
  _AUTHORIZERSERVICE.methods_by_name['ListIdentityAssignments']._options = None
  _AUTHORIZERSERVICE.methods_by_name['ListIdentityAssignments']._serialized_options = b'\202\323\344\223\0020\022./authorizer/api/v1/identities/assignments/list'
  _AUTHORIZERSERVICE.methods_by_name['GetPolicyAssignment']._options = None
  _AUTHORIZERSERVICE.methods_by_name['GetPolicyAssignment']._serialized_options = b'\202\323\344\223\0021\022//authorizer/api/v1/policy_assignments/{id.name}'
  _AUTHORIZERSERVICE.methods_by_name['CreateResource']._options = None
  _AUTHORIZERSERVICE.methods_by_name['CreateResource']._serialized_options = b'\202\323\344\223\002!\"\034/authorizer/api/v1/resources:\001*'
  _AUTHORIZERSERVICE.methods_by_name['DeleteResource']._options = None
  _AUTHORIZERSERVICE.methods_by_name['DeleteResource']._serialized_options = b'\202\323\344\223\002!*\034/authorizer/api/v1/resources:\001*'
  _AUTHORIZERSERVICE.methods_by_name['CreateOrganization']._options = None
  _AUTHORIZERSERVICE.methods_by_name['CreateOrganization']._serialized_options = b'\202\323\344\223\002%\" /authorizer/api/v1/organizations:\001*'
  _AUTHORIZERSERVICE.methods_by_name['GetOrganization']._options = None
  _AUTHORIZERSERVICE.methods_by_name['GetOrganization']._serialized_options = b'\202\323\344\223\0021\022//authorizer/api/v1/organizations/{organization}'
  _AUTHORIZERSERVICE.methods_by_name['DeleteOrganization']._options = None
  _AUTHORIZERSERVICE.methods_by_name['DeleteOrganization']._serialized_options = b'\202\323\344\223\0024*//authorizer/api/v1/organizations/{organization}:\001*'
  _AUTHORIZERSERVICE.methods_by_name['CreatePolicy']._options = None
  _AUTHORIZERSERVICE.methods_by_name['CreatePolicy']._serialized_options = b'\202\323\344\223\002 \"\033/authorizer/api/v1/policies:\001*'
  _AUTHORIZERSERVICE.methods_by_name['GetPolicy']._options = None
  _AUTHORIZERSERVICE.methods_by_name['GetPolicy']._serialized_options = b'\202\323\344\223\002\'\022%/authorizer/api/v1/policies/{id.name}'
  _AUTHORIZERSERVICE.methods_by_name['DeletePolicy']._options = None
  _AUTHORIZERSERVICE.methods_by_name['DeletePolicy']._serialized_options = b'\202\323\344\223\002\'*%/authorizer/api/v1/policies/{id.name}'
  _AUTHORIZERSERVICE.methods_by_name['ListPolicies']._options = None
  _AUTHORIZERSERVICE.methods_by_name['ListPolicies']._serialized_options = b'\202\323\344\223\002\035\022\033/authorizer/api/v1/policies'
  _AUTHORIZERSERVICE.methods_by_name['CreatePolicyBinding']._options = None
  _AUTHORIZERSERVICE.methods_by_name['CreatePolicyBinding']._serialized_options = b'\202\323\344\223\002:\"5/authorizer/api/v1/policies/{policy_id.name}/bindings:\001*'
  _AUTHORIZERSERVICE.methods_by_name['DeletePolicyBinding']._options = None
  _AUTHORIZERSERVICE.methods_by_name['DeletePolicyBinding']._serialized_options = b'\202\323\344\223\002:*5/authorizer/api/v1/policies/{policy_id.name}/bindings:\001*'
  _AUTHORIZERSERVICE.methods_by_name['CreateRole']._options = None
  _AUTHORIZERSERVICE.methods_by_name['CreateRole']._serialized_options = b'\202\323\344\223\002\035\"\030/authorizer/api/v1/roles:\001*'
  _AUTHORIZERSERVICE.methods_by_name['GetRole']._options = None
  _AUTHORIZERSERVICE.methods_by_name['GetRole']._serialized_options = b'\202\323\344\223\002$\022\"/authorizer/api/v1/roles/{id.name}'
  _AUTHORIZERSERVICE.methods_by_name['DeleteRole']._options = None
  _AUTHORIZERSERVICE.methods_by_name['DeleteRole']._serialized_options = b'\202\323\344\223\002$*\"/authorizer/api/v1/roles/{id.name}'
  _AUTHORIZERSERVICE.methods_by_name['ListRoles']._options = None
  _AUTHORIZERSERVICE.methods_by_name['ListRoles']._serialized_options = b'\202\323\344\223\002\032\022\030/authorizer/api/v1/roles'
  _AUTHORIZERSERVICE.methods_by_name['CreateRoleAction']._options = None
  _AUTHORIZERSERVICE.methods_by_name['CreateRoleAction']._serialized_options = b'\202\323\344\223\002/\"*/authorizer/api/v1/roles/{id.name}/actions:\001*'
  _AUTHORIZERSERVICE.methods_by_name['DeleteRoleAction']._options = None
  _AUTHORIZERSERVICE.methods_by_name['DeleteRoleAction']._serialized_options = b'\202\323\344\223\002/**/authorizer/api/v1/roles/{id.name}/actions:\001*'
  _globals['_AUTHORIZERSERVICE']._serialized_start=109
  _globals['_AUTHORIZERSERVICE']._serialized_end=4218
# @@protoc_insertion_point(module_scope)
