# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workspace/workspace_definition_payload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.common import list_pb2 as common_dot_list__pb2
from flyteidl.admin import task_pb2 as flyteidl_dot_admin_dot_task__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2
from union.internal.workspace import workspace_definition_pb2 as workspace_dot_workspace__definition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,workspace/workspace_definition_payload.proto\x12\x12\x63loudidl.workspace\x1a\x11\x63ommon/list.proto\x1a\x19\x66lyteidl/admin/task.proto\x1a\x17validate/validate.proto\x1a$workspace/workspace_definition.proto\"\xf3\x02\n CreateWorkspaceDefinitionRequest\x12K\n\x02id\x18\x01 \x01(\x0b\x32\x31.cloudidl.workspace.WorkspaceDefinitionIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\x18.flyteidl.admin.TaskSpecB\x02\x18\x01R\x04spec\x12/\n\x11short_description\x18\x03 \x01(\tB\x02\x18\x01R\x10shortDescription\x12R\n\x0eworkspace_spec\x18\x04 \x01(\x0b\x32+.cloudidl.workspace.WorkspaceDefinitionSpecR\rworkspaceSpec\x12K\n\"create_workspace_definition_entity\x18\x05 \x01(\x08R\x1f\x63reateWorkspaceDefinitionEntity\"\x7f\n!CreateWorkspaceDefinitionResponse\x12Z\n\x14workspace_definition\x18\x01 \x01(\x0b\x32\'.cloudidl.workspace.WorkspaceDefinitionR\x13workspaceDefinition\"l\n\x1dGetWorkspaceDefinitionRequest\x12K\n\x02id\x18\x01 \x01(\x0b\x32\x31.cloudidl.workspace.WorkspaceDefinitionIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\"|\n\x1eGetWorkspaceDefinitionResponse\x12Z\n\x14workspace_definition\x18\x01 \x01(\x0b\x32\'.cloudidl.workspace.WorkspaceDefinitionR\x13workspaceDefinition\"\xf2\x02\n UpdateWorkspaceDefinitionRequest\x12K\n\x02id\x18\x01 \x01(\x0b\x32\x31.cloudidl.workspace.WorkspaceDefinitionIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\x18.flyteidl.admin.TaskSpecB\x02\x18\x01R\x04spec\x12\x46\n\x05state\x18\x03 \x01(\x0e\x32,.cloudidl.workspace.WorkspaceDefinitionStateB\x02\x18\x01R\x05state\x12/\n\x11short_description\x18\x04 \x01(\tB\x02\x18\x01R\x10shortDescription\x12R\n\x0eworkspace_spec\x18\x05 \x01(\x0b\x32+.cloudidl.workspace.WorkspaceDefinitionSpecR\rworkspaceSpec:\x02\x18\x01\"\x7f\n!UpdateWorkspaceDefinitionResponse\x12Z\n\x14workspace_definition\x18\x01 \x01(\x0b\x32\'.cloudidl.workspace.WorkspaceDefinitionR\x13workspaceDefinition\"\xc3\x01\n\x1fListWorkspaceDefinitionsRequest\x12\x10\n\x03org\x18\x01 \x01(\tR\x03org\x12!\n\x07project\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x07project\x12\x1f\n\x06\x64omain\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x64omain\x12\x12\n\x04name\x18\x05 \x01(\tR\x04name\x12\x36\n\x07request\x18\x04 \x01(\x0b\x32\x1c.cloudidl.common.ListRequestR\x07request\"\x96\x01\n ListWorkspaceDefinitionsResponse\x12\\\n\x15workspace_definitions\x18\x01 \x03(\x0b\x32\'.cloudidl.workspace.WorkspaceDefinitionR\x14workspaceDefinitions\x12\x14\n\x05token\x18\x02 \x01(\tR\x05token\"\xb6\x01\n&ListWorkspaceDefinitionEntitiesRequest\x12\x10\n\x03org\x18\x01 \x01(\tR\x03org\x12!\n\x07project\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x07project\x12\x1f\n\x06\x64omain\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x64omain\x12\x36\n\x07request\x18\x04 \x01(\x0b\x32\x1c.cloudidl.common.ListRequestR\x07request\"\xb2\x01\n\'ListWorkspaceDefinitionEntitiesResponse\x12q\n\x1dworkspace_definition_entities\x18\x01 \x03(\x0b\x32-.cloudidl.workspace.WorkspaceDefinitionEntityR\x1bworkspaceDefinitionEntities\x12\x14\n\x05token\x18\x02 \x01(\tR\x05token\"y\n&UpdateWorkspaceDefinitionEntityRequest\x12O\n\x06\x65ntity\x18\x01 \x01(\x0b\x32-.cloudidl.workspace.WorkspaceDefinitionEntityB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x06\x65ntity\")\n\'UpdateWorkspaceDefinitionEntityResponseB\xd2\x01\n\x16\x63om.cloudidl.workspaceB\x1fWorkspaceDefinitionPayloadProtoH\x02P\x01Z,github.com/unionai/cloud/gen/pb-go/workspace\xa2\x02\x03\x43WX\xaa\x02\x12\x43loudidl.Workspace\xca\x02\x12\x43loudidl\\Workspace\xe2\x02\x1e\x43loudidl\\Workspace\\GPBMetadata\xea\x02\x13\x43loudidl::Workspaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workspace.workspace_definition_payload_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.cloudidl.workspaceB\037WorkspaceDefinitionPayloadProtoH\002P\001Z,github.com/unionai/cloud/gen/pb-go/workspace\242\002\003CWX\252\002\022Cloudidl.Workspace\312\002\022Cloudidl\\Workspace\342\002\036Cloudidl\\Workspace\\GPBMetadata\352\002\023Cloudidl::Workspace'
  _CREATEWORKSPACEDEFINITIONREQUEST.fields_by_name['id']._options = None
  _CREATEWORKSPACEDEFINITIONREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEWORKSPACEDEFINITIONREQUEST.fields_by_name['spec']._options = None
  _CREATEWORKSPACEDEFINITIONREQUEST.fields_by_name['spec']._serialized_options = b'\030\001'
  _CREATEWORKSPACEDEFINITIONREQUEST.fields_by_name['short_description']._options = None
  _CREATEWORKSPACEDEFINITIONREQUEST.fields_by_name['short_description']._serialized_options = b'\030\001'
  _GETWORKSPACEDEFINITIONREQUEST.fields_by_name['id']._options = None
  _GETWORKSPACEDEFINITIONREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UPDATEWORKSPACEDEFINITIONREQUEST.fields_by_name['id']._options = None
  _UPDATEWORKSPACEDEFINITIONREQUEST.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UPDATEWORKSPACEDEFINITIONREQUEST.fields_by_name['spec']._options = None
  _UPDATEWORKSPACEDEFINITIONREQUEST.fields_by_name['spec']._serialized_options = b'\030\001'
  _UPDATEWORKSPACEDEFINITIONREQUEST.fields_by_name['state']._options = None
  _UPDATEWORKSPACEDEFINITIONREQUEST.fields_by_name['state']._serialized_options = b'\030\001'
  _UPDATEWORKSPACEDEFINITIONREQUEST.fields_by_name['short_description']._options = None
  _UPDATEWORKSPACEDEFINITIONREQUEST.fields_by_name['short_description']._serialized_options = b'\030\001'
  _UPDATEWORKSPACEDEFINITIONREQUEST._options = None
  _UPDATEWORKSPACEDEFINITIONREQUEST._serialized_options = b'\030\001'
  _LISTWORKSPACEDEFINITIONSREQUEST.fields_by_name['project']._options = None
  _LISTWORKSPACEDEFINITIONSREQUEST.fields_by_name['project']._serialized_options = b'\372B\004r\002\020\001'
  _LISTWORKSPACEDEFINITIONSREQUEST.fields_by_name['domain']._options = None
  _LISTWORKSPACEDEFINITIONSREQUEST.fields_by_name['domain']._serialized_options = b'\372B\004r\002\020\001'
  _LISTWORKSPACEDEFINITIONENTITIESREQUEST.fields_by_name['project']._options = None
  _LISTWORKSPACEDEFINITIONENTITIESREQUEST.fields_by_name['project']._serialized_options = b'\372B\004r\002\020\001'
  _LISTWORKSPACEDEFINITIONENTITIESREQUEST.fields_by_name['domain']._options = None
  _LISTWORKSPACEDEFINITIONENTITIESREQUEST.fields_by_name['domain']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEWORKSPACEDEFINITIONENTITYREQUEST.fields_by_name['entity']._options = None
  _UPDATEWORKSPACEDEFINITIONENTITYREQUEST.fields_by_name['entity']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_CREATEWORKSPACEDEFINITIONREQUEST']._serialized_start=178
  _globals['_CREATEWORKSPACEDEFINITIONREQUEST']._serialized_end=549
  _globals['_CREATEWORKSPACEDEFINITIONRESPONSE']._serialized_start=551
  _globals['_CREATEWORKSPACEDEFINITIONRESPONSE']._serialized_end=678
  _globals['_GETWORKSPACEDEFINITIONREQUEST']._serialized_start=680
  _globals['_GETWORKSPACEDEFINITIONREQUEST']._serialized_end=788
  _globals['_GETWORKSPACEDEFINITIONRESPONSE']._serialized_start=790
  _globals['_GETWORKSPACEDEFINITIONRESPONSE']._serialized_end=914
  _globals['_UPDATEWORKSPACEDEFINITIONREQUEST']._serialized_start=917
  _globals['_UPDATEWORKSPACEDEFINITIONREQUEST']._serialized_end=1287
  _globals['_UPDATEWORKSPACEDEFINITIONRESPONSE']._serialized_start=1289
  _globals['_UPDATEWORKSPACEDEFINITIONRESPONSE']._serialized_end=1416
  _globals['_LISTWORKSPACEDEFINITIONSREQUEST']._serialized_start=1419
  _globals['_LISTWORKSPACEDEFINITIONSREQUEST']._serialized_end=1614
  _globals['_LISTWORKSPACEDEFINITIONSRESPONSE']._serialized_start=1617
  _globals['_LISTWORKSPACEDEFINITIONSRESPONSE']._serialized_end=1767
  _globals['_LISTWORKSPACEDEFINITIONENTITIESREQUEST']._serialized_start=1770
  _globals['_LISTWORKSPACEDEFINITIONENTITIESREQUEST']._serialized_end=1952
  _globals['_LISTWORKSPACEDEFINITIONENTITIESRESPONSE']._serialized_start=1955
  _globals['_LISTWORKSPACEDEFINITIONENTITIESRESPONSE']._serialized_end=2133
  _globals['_UPDATEWORKSPACEDEFINITIONENTITYREQUEST']._serialized_start=2135
  _globals['_UPDATEWORKSPACEDEFINITIONENTITYREQUEST']._serialized_end=2256
  _globals['_UPDATEWORKSPACEDEFINITIONENTITYRESPONSE']._serialized_start=2258
  _globals['_UPDATEWORKSPACEDEFINITIONENTITYRESPONSE']._serialized_end=2299
# @@protoc_insertion_point(module_scope)
