# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: app/replica_definition.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from union.internal.app import app_definition_pb2 as app_dot_app__definition__pb2
from union.internal.validate.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61pp/replica_definition.proto\x12\x0c\x63loudidl.app\x1a\x18\x61pp/app_definition.proto\x1a\x17validate/validate.proto\"k\n\x11ReplicaIdentifier\x12\x39\n\x06\x61pp_id\x18\x01 \x01(\x0b\x32\x18.cloudidl.app.IdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x05\x61ppId\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\"d\n\x0bReplicaMeta\x12\x39\n\x02id\x18\x01 \x01(\x0b\x32\x1f.cloudidl.app.ReplicaIdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x02id\x12\x1a\n\x08revision\x18\x02 \x01(\x04R\x08revision\":\n\x0bReplicaList\x12+\n\x05items\x18\x01 \x03(\x0b\x32\x15.cloudidl.app.ReplicaR\x05items\"\x7f\n\x07Replica\x12?\n\x08metadata\x18\x01 \x01(\x0b\x32\x19.cloudidl.app.ReplicaMetaB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x08metadata\x12\x33\n\x06status\x18\x02 \x01(\x0b\x32\x1b.cloudidl.app.ReplicaStatusR\x06status\"T\n\rReplicaStatus\x12+\n\x11\x64\x65ployment_status\x18\x01 \x01(\tR\x10\x64\x65ploymentStatus\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reasonB\xa5\x01\n\x10\x63om.cloudidl.appB\x16ReplicaDefinitionProtoH\x02P\x01Z&github.com/unionai/cloud/gen/pb-go/app\xa2\x02\x03\x43\x41X\xaa\x02\x0c\x43loudidl.App\xca\x02\x0c\x43loudidl\\App\xe2\x02\x18\x43loudidl\\App\\GPBMetadata\xea\x02\rCloudidl::Appb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'app.replica_definition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020com.cloudidl.appB\026ReplicaDefinitionProtoH\002P\001Z&github.com/unionai/cloud/gen/pb-go/app\242\002\003CAX\252\002\014Cloudidl.App\312\002\014Cloudidl\\App\342\002\030Cloudidl\\App\\GPBMetadata\352\002\rCloudidl::App'
  _REPLICAIDENTIFIER.fields_by_name['app_id']._options = None
  _REPLICAIDENTIFIER.fields_by_name['app_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _REPLICAIDENTIFIER.fields_by_name['name']._options = None
  _REPLICAIDENTIFIER.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _REPLICAMETA.fields_by_name['id']._options = None
  _REPLICAMETA.fields_by_name['id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _REPLICA.fields_by_name['metadata']._options = None
  _REPLICA.fields_by_name['metadata']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_REPLICAIDENTIFIER']._serialized_start=97
  _globals['_REPLICAIDENTIFIER']._serialized_end=204
  _globals['_REPLICAMETA']._serialized_start=206
  _globals['_REPLICAMETA']._serialized_end=306
  _globals['_REPLICALIST']._serialized_start=308
  _globals['_REPLICALIST']._serialized_end=366
  _globals['_REPLICA']._serialized_start=368
  _globals['_REPLICA']._serialized_end=495
  _globals['_REPLICASTATUS']._serialized_start=497
  _globals['_REPLICASTATUS']._serialized_end=581
# @@protoc_insertion_point(module_scope)
